References — suffix-tree 0.1.1 documentation

# References

[Gusfield1997]

Gusfield, Dan. Algorithms on strings, trees, and sequences. 1997. Cambridge University Press.

[McCreight1976]

McCreight, Edward. A Space-Economical Suffix Tree Construction Algorithm. Journal of the Association for Computing Machinery, Vol 23, No. 2, April 1976 https://dl.acm.org/doi/pdf/10.1145/321941.321946

[Ukkonen1995]

Ukkonen, Esko. On-line construction of suffix trees. 1995. Algorithmica 14:249-60. http://www.cs.helsinki.fi/u/ukkonen/SuffixT1withFigs.pdf

[Warren2013]

Warren, H.S. Hacker’s Delight. 2nd Edition 2013. Pearson, Westford, MA.